@@ -69,7 +69,7 @@ test_that(
         value = c(
           paste("poio", packageDescription("poio", fields = "Version")),
           "https://github.com/RL10N/poio/issues", "2016-10-05 20:19",
-          "DUMMY VALUE", me, "LANGUAGE <LL@li.org>",
+          "DUMMY VALUE", me, "",
           "1.0", "text/plain; charset=UTF-8", "8bit"
         )
       ),
@@ -107,6 +107,72 @@ test_that(
   }
 )
 
+test_that(
+  "fix_metadata works with user-specified metadata",
+  {
+    pot_file <- system.file("extdata/R-empty-raw.pot", package = "poio")
+    project_id_version <- "99.9.9"
+    report_msgid_bugs_to <- "Definitely Thomas not Richie"
+    last_translator <- "The Girl with the Babel Fish"
+
+    expected <- po(
+      source_type = "r",
+      file_type   = "pot",
+      initial_comments = character(),
+      metadata    = tibble::data_frame(
+        name = c(
+          "Project-Id-Version", "Report-Msgid-Bugs-To", "POT-Creation-Date",
+          "PO-Revision-Date", "Last-Translator", "Language-Team",
+          "MIME-Version", "Content-Type", "Content-Transfer-Encoding"
+        ),
+        value = c(
+          project_id_version,
+          report_msgid_bugs_to, "2016-10-05 20:19",
+          "DUMMY VALUE", last_translator, "",
+          "1.0", "text/plain; charset=UTF-8", "8bit"
+        )
+      ),
+      direct = poio:::append_key(
+        tibble::data_frame(
+          msgid                     = character(),
+          msgstr                    = character(),
+          is_obsolete               = logical(),
+          msgctxt                   = list(),
+          translator_comments       = list(),
+          source_reference_comments = list(),
+          flags_comments            = list(),
+          previous_string_comments  = list()
+        )
+      ),
+      countable = poio:::append_key(
+        tibble::data_frame(
+          msgid                     = character(),
+          msgid_plural              = character(),
+          msgstr                    = list(),
+          is_obsolete               = logical(),
+          msgctxt                   = list(),
+          translator_comments       = list(),
+          source_reference_comments = list(),
+          flags_comments            = list(),
+          previous_string_comments  = list()
+        )
+      )
+    )
+    pot <- read_po(pot_file)
+    pkg <- devtools::as.package(system.file(package = "poio"))
+    expect_true(is.list(pkg))
+    actual <- fix_metadata(
+      pot, pkg,
+      "Project-Id-Version" = project_id_version,
+      .dots = list(
+        "Report-Msgid-Bugs-To" = report_msgid_bugs_to,
+        "Last-Translator" = last_translator
+      )
+    )
+    expect_po_equal(actual, expected, check_po_revision_date = TRUE)
+  }
+)
+
 test_that(
   "write_po works on an empty POT file",
   {
